# credits to Anarov for improved example.py
# https://github.com/Anorov/py-4chan

import sys
sys.path.insert(0, '../')

import py4chan

b = py4chan.Board('b')
threads = b.get_threads()
print("Got %i threads" % len(threads))
first_thread = threads[0]
print("First thread: %r" % first_thread)
print("Replies: %r" % first_thread.replies)
print("Updating first thread...")
first_thread.update()
print("First thread now: %r" % first_thread)
for post in first_thread.replies:
    print(post.post_url)



# credits to Anarov for improved example.py
# https://github.com/Anorov/py-4chan
import sys
sys.path.insert(0, '../')

import py4chan

def main():
    v = py4chan.Board('v')
    thread = v.get_thread(152900882)
    print(thread)
    print('Sticky?', thread.sticky)
    print('Closed?', thread.closed)
    topic = thread.topic
    print('Topic Repr', topic)
    print('Postnumber', topic.post_number)
    print('Timestamp',  topic.timestamp)
    print('Datetime',   repr(topic.datetime))
    print('Filemd5hex', topic.file_md5_hex)
    print('Fileurl',    topic.file_url)
    print('Subject',    topic.subject)
    print('Comment',    topic.comment)
    print('Thumbnailurl',topic.thumbnail_url)
    print('Replies',    thread.replies)
    print('All posts',  thread.all_posts)


if __name__ == '__main__':
    main()


# credits to Anarov for improved example.py
# https://github.com/Anorov/py-4chan

import sys
sys.path.insert(0, '../')

import py4chan

def main():
    if len(sys.argv) != 3:
        print("Usage: python %s [board] [thread]" % sys.argv[0])
        print("Shows the URL of all the files in the thread.")
        print("Example (download all files in thread): python %s v 12351234 | xargs wget" % sys.argv[0])
        return

    board = py4chan.Board(sys.argv[1])
    thread = board.get_thread(int(sys.argv[2]))
    for file in thread.files():
        print(file)

if __name__ == '__main__':
    main()